@@ -16,7 +16,7 @@ import mbedtls.tls as tls
 import mbedtls.version as version
 import mbedtls.x509 as x509
 
-hash = hashlib  # pylint: disable=redefined-builtin
+__version__ = "1.5.0"
 
 __all__ = (
     "cipher",
