@@ -1,3 +1,6 @@
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2019, Mathias Laurin
+
 """The ARIA algorithm is a symmetric block cipher that can encrypt and
 decrypt information. It is defined by the Korean Agency for Technology
 and Standards (KATS) in *KS X 1213:2004* (in Korean, but see
@@ -6,13 +9,10 @@ the IETF in *RFC 5794*.
 
 """
 
-__author__ = "Mathias Laurin"
-__copyright__ = "Copyright 2019, Mathias Laurin"
-__license__ = "MIT License"
 
+from mbedtls.exceptions import TLSError
 
 from . import _cipher
-from mbedtls.exceptions import *
 
 __all__ = ["block_size", "key_size", "new"]
 
@@ -22,6 +22,22 @@ key_size = None
 
 
 def new(key, mode, iv=None):
+    """Return a `Cipher` object that can perform ARIA encryption and
+    decryption.
+
+    ARIA is a block cipher designed in 2003 by a large group of South
+    Korean researchers. In 2004, the Korean Agency for Technology and
+    Standards selected it as a standard cryptographic technique.
+
+    Parameters:
+        key (bytes): The key to encrypt decrypt.
+        mode (int): The mode of operation of the cipher.
+        iv (bytes or None): The initialization vector (IV).  The IV is
+            required for every mode but ECB and CTR where it is ignored.
+            If not set, the IV is initialized to all 0, which should not
+            be used for encryption.
+
+    """
     mode = _cipher.Mode(mode)
     if mode in {
         _cipher.Mode.ECB,
