@@ -23,17 +23,17 @@ def test_get_supported_ciphers():
 
 
 def test_wrong_size_raises_exception():
-    with pytest.raises(TLSError):
+    with pytest.raises(NotImplementedError):
         Cipher(b"AES-512-ECB", b"", mb.Mode.ECB, b"")
 
 
 def test_random_name_raises_exception():
-    with pytest.raises(TLSError):
+    with pytest.raises(NotImplementedError):
         Cipher(b"RANDOM TEXT IS NOT A CIPHER", b"", mb.Mode.ECB, b"")
 
 
 def test_zero_length_raises_exception():
-    with pytest.raises(TLSError):
+    with pytest.raises(NotImplementedError):
         Cipher(b"", b"", mb.Mode.ECB, b"")
 
 
@@ -76,7 +76,7 @@ class _TestCipher:
         return request.param
 
     @pytest.fixture
-    def iv_size(self):
+    def iv_size(self, mode):
         raise NotImplementedError
 
     @pytest.fixture
@@ -109,7 +109,10 @@ class _TestCipher:
 
     @pytest.fixture
     def cipher(self, module, key, mode, iv):
-        return module.new(key, mode, iv)
+        try:
+            return module.new(key, mode, iv)
+        except NotImplementedError:
+            return pytest.skip("unsupported cipher")
 
     @pytest.fixture
     def data(self, cipher, mode, randbytes):
@@ -211,7 +214,7 @@ class TestAES(_TestAESBase):
 
     @pytest.fixture
     def iv_size(self, mode):
-        return 0 if mode is mb.Mode.ECB else 16
+        return {mb.Mode.ECB: 0}.get(mode, 16)
 
     @pytest.fixture(params=[16, 24, 32])
     def key_size(self, request):
@@ -224,8 +227,8 @@ class TestAES_XTS(_TestAESBase):
         return request.param
 
     @pytest.fixture
-    def iv_size(self):
-        return 16
+    def iv_size(self, mode):
+        return {mb.Mode.ECB: 0}.get(mode, 16)
 
     @pytest.fixture(params=[32, 64])
     def key_size(self, request):
@@ -242,8 +245,8 @@ class TestAES_AEAD(_TestAEADCipher):
         return request.param
 
     @pytest.fixture
-    def iv_size(self):
-        return 12
+    def iv_size(self, mode):
+        return {mb.Mode.ECB: 0}.get(mode, 12)
 
     @pytest.fixture(params=[16, 24, 32])
     def key_size(self, request):
@@ -264,8 +267,8 @@ class TestARC4(_TestCipher):
         return request.param
 
     @pytest.fixture
-    def iv_size(self):
-        return 0
+    def iv_size(self, mode):
+        return {mb.Mode.ECB: 0}.get(mode, 0)
 
     @pytest.fixture(params=[16])
     def key_size(self, request):
@@ -311,7 +314,7 @@ class TestARIA(_TestCipher):
 
     @pytest.fixture
     def iv_size(self, mode):
-        return 12 if mode is mb.Mode.GCM else 16
+        return {mb.Mode.ECB: 0, mb.Mode.GCM: 12}.get(mode, 16)
 
     @pytest.fixture(params=[16, 24, 32])
     def key_size(self, request):
@@ -356,8 +359,8 @@ class TestBlowfish(_TestCipher):
         return request.param
 
     @pytest.fixture
-    def iv_size(self):
-        return 8
+    def iv_size(self, mode):
+        return {mb.Mode.ECB: 0}.get(mode, 8)
 
     @pytest.fixture(params=range(4, 57))
     def key_size(self, request):
@@ -407,7 +410,7 @@ class TestCamellia(_TestCipher):
 
     @pytest.fixture
     def iv_size(self, mode):
-        return 12 if mode is mb.Mode.GCM else 16
+        return {mb.Mode.ECB: 0, mb.Mode.GCM: 12}.get(mode, 16)
 
     @pytest.fixture(params=[16, 24, 32])
     def key_size(self, request):
@@ -446,8 +449,8 @@ class _TestDESBase(_TestCipher):
         return request.param
 
     @pytest.fixture
-    def iv_size(self):
-        return 8
+    def iv_size(self, mode):
+        return {mb.Mode.ECB: 0}.get(mode, 8)
 
     @pytest.fixture(params=[4, 64])
     def invalid_key_size(self, request):
@@ -509,8 +512,8 @@ class TestCHACHA20(_TestCipher):
         return request.param
 
     @pytest.fixture
-    def iv_size(self):
-        return 12
+    def iv_size(self, mode):
+        return {mb.Mode.ECB: 0}.get(mode, 12)
 
     @pytest.fixture(params=[32])
     def key_size(self, request):
@@ -552,8 +555,8 @@ class TestCHACHA20AEAD(_TestAEADCipher):
         return request.param
 
     @pytest.fixture
-    def iv_size(self):
-        return 12
+    def iv_size(self, mode):
+        return {mb.Mode.ECB: 0}.get(mode, 12)
 
     @pytest.fixture(params=[32])
     def key_size(self, request):
